.. title:: parselglossy

============
parselglossy
============

.. epigraph::

   [...] I speak with tongues more than you all;

   -- **1 Corinthians** 14:18

   Parse it on!

   -- Bobson Dugnutt, **Private communication**


Generic input parsing library, speaking in tongues.

.. toctree::
   :maxdepth: 1
   :caption: Contents:

   design
   installation
   usage
   contributing
   authors
   history
   modules

Indices and tables
==================
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
